<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category XEvent
 * @package  Custom Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */


/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 object $cmb CMB2 object
 *
 * @return bool             True if metabox should show
 */
function yourprefix_show_if_front_page( $cmb ) {
	// Don't show this metabox if it's not the front page template
	if ( $cmb->object_id !== get_option( 'page_on_front' ) ) {
		return false;
	}
	return true;
}

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field object $field Field object
 *
 * @return bool                     True if metabox should show
 */
function yourprefix_hide_if_no_cats( $field ) {
	// Don't show this field if not in the cats category
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}
	return true;
}

/**
 * Manually render a field.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object
 */
function yourprefix_render_row_cb( $field_args, $field ) {
	$classes     = $field->row_classes();
	$id          = $field->args( 'id' );
	$label       = $field->args( 'name' );
	$name        = $field->args( '_name' );
	$value       = $field->escaped_value();
	$description = $field->args( 'description' );
	?>
	<div class="custom-field-row <?php echo $classes; ?>">
		<p><label for="<?php echo $id; ?>"><?php echo $label; ?></label></p>
		<p><input id="<?php echo $id; ?>" type="text" name="<?php echo $name; ?>" value="<?php echo $value; ?>"/></p>
		<p class="description"><?php echo $description; ?></p>
	</div>
	<?php
}

/**
 * Manually render a field column display.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object
 */
function yourprefix_display_text_small_column( $field_args, $field ) {
	?>
	<div class="custom-column-display <?php echo $field->row_classes(); ?>">
		<p><?php echo $field->escaped_value(); ?></p>
		<p class="description"><?php echo $field->args( 'description' ); ?></p>
	</div>
	<?php
}

/**
 * Conditionally displays a message if the $post_id is 2
 *
 * @param  array             $field_args Array of field parameters
 * @param  CMB2_Field object $field      Field object
 */
function yourprefix_before_row_if_2( $field_args, $field ) {
	if ( 2 == $field->object_id ) {
		echo '<p>Testing <b>"before_row"</b> parameter (on $post_id 2)</p>';
	} else {
		echo '<p>Testing <b>"before_row"</b> parameter (<b>NOT</b> on $post_id 2)</p>';
	}
}

add_action( 'cmb2_admin_init', 'tc_metabox' );
/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
function tc_metabox() {
	$prefix = 'tc_';


    //Sponsor
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_sponsors',
		'title'         => esc_html__( 'Sponsors Details', 'xevent' ),
		'object_types'  => array( 'sponsors', ), // Post type
	) );

	$cmb->add_field( array(
		'name'       => esc_html__( 'Special Label(Optional', 'xevent' ),
		'id'         => $prefix . 'sponsor_label',
		'type'       => 'text_medium',
	) );
	

	//Speaker
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_speaker',
		'title'         => esc_html__( 'Speaker Details', 'xevent' ),
		'object_types'  => array( 'speaker', ), // Post type
	) );

	$cmb->add_field( array(
		'name'       => esc_html__( 'Company', 'xevent' ),
		'id'         => $prefix . 'speaker_company',
		'type'       => 'text_medium',
	) );

	$cmb->add_field( array(
		'name'       => esc_html__( 'Job title', 'xevent' ),
		'id'         => $prefix . 'speaker_job',
		'type'       => 'text',
	) );

    $cmb->add_field( array(
    		'name'       => esc_html__( 'Customized Speaker Chair Title', 'xevent' ),
    		'id'         => $prefix . 'speaker_chair_title',
    		'type'       => 'text',
    ) ); 

	$cmb->add_field( array(
		'name' => esc_html__( 'Website URL', 'xevent' ),
		'id'   => $prefix . 'speaker_website',
		'type' => 'text_url',
	) );

    $cmb->add_field( array(
		'name' => esc_html__( 'Company Logo (260x120)', 'xevent' ),
		'desc' => esc_html__( 'Upload an image or enter a URL.', 'xevent' ),
		'id'   => $prefix . 'speaker_big_image',
		'type' => 'file',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Facebook Address', 'xevent' ),
		'id'   => $prefix . 'speaker_fb_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Twitter Address', 'xevent' ),
		'id'   => $prefix . 'speaker_tw_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Instagram Address', 'xevent' ),
		'id'   => $prefix . 'speaker_instagram_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Google Plus Address', 'xevent' ),
		'id'   => $prefix . 'speaker_gplus_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Linkedin Address', 'xevent' ),
		'id'   => $prefix . 'speaker_linkedin_address',
		'type' => 'text_url',
	) );


	// Featured Speaker
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_speaker_featured',
		'title'         => esc_html__( 'Keynote Speaker', 'xevent' ),
		'object_types'  => array( 'speaker', ), // Post type
		'context'    => 'side',
		'priority'   => 'low',
		'cmb_styles' => false, // false to disable the CMB stylesheet

	) );

	$cmb->add_field( array(
	  //'name' => 'Featured Speaker',
	    'desc' => 'Keynote Speaker',
	    'id'   => $prefix . 'featured_speaker',
	    'type' => 'checkbox'
	) );


	//Team Member
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_member',
		'title'         => esc_html__( 'Team Member Details', 'xevent' ),
		'object_types'  => array( 'member', ), // Post type
	) );


	$cmb->add_field( array(
		'name'       => esc_html__( 'Job title', 'xevent' ),
		'id'         => $prefix . 'member_job',
		'type'       => 'text',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Website URL', 'xevent' ),
		'id'   => $prefix . 'member_website',
		'type' => 'text_url',
	) );

    $cmb->add_field( array(
		'name' => esc_html__( 'Member Big image (optional)', 'xevent' ),
		'desc' => esc_html__( 'Upload an image or enter a URL.', 'xevent' ),
		'id'   => $prefix . 'member_big_image',
		'type' => 'file',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Facebook Address', 'xevent' ),
		'id'   => $prefix . 'member_fb_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Twitter Address', 'xevent' ),
		'id'   => $prefix . 'member_tw_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Instagram Address', 'xevent' ),
		'id'   => $prefix . 'member_instagram_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Google Plus Address', 'xevent' ),
		'id'   => $prefix . 'member_gplus_address',
		'type' => 'text_url',
	) );

	$cmb->add_field( array(
		'name' => esc_html__( 'Linkedin Address', 'xevent' ),
		'id'   => $prefix . 'member_linkedin_address',
		'type' => 'text_url',
	) );


	// Additional Info for Schedule
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_program_additional',
		'title'         => esc_html__( 'Additional Info', 'xevent' ),
		'object_types'  => array( 'schedule', ), // Post type
		'context'    => 'side',
		'priority'   => 'low',
		'cmb_styles' => false, // false to disable the CMB stylesheet

	) );

	$cmb->add_field( array(
	  //'name' => 'Additional Info',
	    'id'   => $prefix . 'additional_info',
	    'type'             => 'radio',
	    'options'          => array(
	        'coffee-break' 	=> __( 'Coffee break', 'xevent' ),
	        'lunch'   		=> __( 'Lunch', 'xevent' ),
	        'registration'	=> __( 'Registration', 'xevent' ),
	    ),
	) );

	// Featured Talks
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_schedule_featured',
		'title'         => esc_html__( 'Featured Talk', 'xevent' ),
		'object_types'  => array( 'schedule', ), // Post type
		'context'    => 'side',
		'priority'   => 'low',
		'cmb_styles' => false, // false to disable the CMB stylesheet

	) );

	$cmb->add_field( array(
	    'desc' => 'Featured Talk',
	    'id'   => $prefix . 'featured_talk',
	    'type' => 'checkbox'
	) );

	//Schedule Metaboxes
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_program',
		'title'         => esc_html__( 'Program Details', 'xevent' ),
		'object_types'  => array( 'schedule', ), // Post type
	) );

    //Speaker's Role
    $cmb->add_field( array(
    	'name' => esc_html__( 'Show Speaker Role', 'xevent' ),
    	'id'                => $prefix . 'show_speaker_role',
    	'type'              => 'radio_inline',
    	'options_cb'		=> 'speaker_role_options',
        'default' 			=> 'yes',
    ) );

	//Date
	$cmb->add_field( array(
		'name' => esc_html__( 'Program Date', 'xevent' ),
		'desc' => esc_html__( 'Pick a date for program', 'xevent' ),
		'id'   => $prefix . 'program_date',
		'type' => 'text_date',
		'date_format' => 'M j, Y',
	) );

	//Start Time
	$cmb->add_field( array(
		'name' => esc_html__( 'Start Time', 'xevent' ),
		'desc' => esc_html__( 'Select time for program', 'xevent' ),
		'id'   => $prefix . 'program_time',
		'type' => 'text_time',
		'time_format' => 'H:i', // Set to 24hr format
	) );

	//Duration
	$cmb->add_field( array(
		'name' => esc_html__( 'Duration', 'xevent' ),
		'id'   => $prefix . 'program_duration',
		'type' => 'text_small',
	) );

    // Brought to you by image
    $cmb->add_field( array(
    'name' => esc_html__( 'Hosted by Logo (260x120)', 'xevent' ),
    'desc' => esc_html__( 'Upload an image or enter a URL.', 'xevent' ),
    'id' => $prefix . 'schedule_broughby_image',
    'type' => 'file',
    ) );

	//Location
	$cmb->add_field( array(
		'name' => esc_html__( 'Location', 'xevent' ),
		'id'   => $prefix . 'program_location',
		'type' => 'text_medium',
	) );

	//Level
	$cmb->add_field( array(
		'name' => esc_html__( 'Level', 'xevent' ),
		'desc' => esc_html__('Select level (beginner, intermediate, expert etc.)', 'xevent'),
		'id'   => $prefix . 'program_level',
		'type' => 'text_medium',
	) );


	//Workshop Metaboxes
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_workshop',
		'title'         => esc_html__( 'Workshop Details', 'xevent' ),
		'object_types'  => array( 'workshop', ), // Post type
	) );

	//Date
	$cmb->add_field( array(
		'name' => esc_html__( 'Workshop Date', 'xevent' ),
		'desc' => esc_html__( 'Pick a date for workshop', 'xevent' ),
		'id'   => $prefix . 'wshop_date',
		'type' => 'text_date',
		'date_format' => 'M j, Y',
	) );

	//Start Time
	$cmb->add_field( array(
		'name' => esc_html__( 'Start Time', 'xevent' ),
		'desc' => esc_html__( 'Select time for workshop', 'xevent' ),
		'id'   => $prefix . 'wshop_time',
		'type' => 'text_time',
		'time_format' => 'H:i', // Set to 24hr format
	) );

	//Location
	$cmb->add_field( array(
		'name' => esc_html__( 'Location', 'xevent' ),
		'id'   => $prefix . 'wshop_location',
		'type' => 'text_medium',
	) );

	//Prerequisites
	$cmb->add_field( array(
		'name' => esc_html__( 'Prerequisites', 'xevent' ),
		'id'   => $prefix . 'prerequisites',
		'type' => 'textarea',
	) );


	
	//Header Settings
	$cmb = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_header',
		'title'         => esc_html__( 'Header Settings', 'xevent' ),
		'object_types'  => array( 'page','schedule', 'workshop' ), // Post type
	) );

	//Header Background
    $cmb->add_field( array(
		'name' => esc_html__( 'Header Background Image', 'xevent' ),
		'desc' => esc_html__( 'Upload an image or enter a URL.', 'xevent' ),
		'id'   => $prefix . 'header_bg',
		'type' => 'file',
	) );

	//Background Effect
	$cmb->add_field( array(
		'name'             => esc_html__( 'Background Effect', 'xevent' ),
		'id'               => $prefix . 'bg_effect',
		'type'             => 'radio',
		'show_option_none' => 'No effect',
		'required'            => true,
		'options'          => array(
			'bw' 		=> esc_html__( 'Black & White', 'xevent' ),
			'blended'   => esc_html__( 'Blended', 'xevent' ),
			'rainbow'	=> esc_html__( 'Gradient', 'xevent' ),
			
		),
	) );

	// Gradient Ext. 
	$cmb->add_field( array(
		'name'       => esc_html__( 'Degree', 'xevent' ),
		'id'         => $prefix . 'degree',
		'type'       => 'text_small',
		'default'	 => '135',
		'attributes' => array(
			'data-conditional-id'    => $prefix . 'bg_effect',
			'data-conditional-value' => 'rainbow',
		),
	) );

	// Color 1
	$cmb->add_field( array(
		'name'    => esc_html__( 'Color 1', 'xevent' ),
		'id'      => $prefix . 'color1',
		'type'    => 'text_small',
		'default' => '1D77EF',
		'desc'	  => esc_html__('Add color code without #', 'xevent'),
		'attributes' => array(
			'data-conditional-id'    => $prefix . 'bg_effect',
			'data-conditional-value' => 'rainbow',
		),
	) );

	//Color 2
	$cmb->add_field( array(
		'name'    => esc_html__( 'Color 2', 'xevent' ),
		'id'      => $prefix . 'color2',
		'type'    => 'text_small',
		'default' => '81F3FD',
		'desc'	  => esc_html__('Add color code without #', 'xevent'),
		'attributes' => array(
			'data-conditional-id'    => $prefix . 'bg_effect',
			'data-conditional-value' => 'rainbow',
		),
	) );

	//Opacity
	$cmb->add_field( array(
		'name'       => esc_html__( 'Opacity', 'xevent' ),
		'id'         => $prefix . 'opacity',
		'type'       => 'text_small',
		'default'	 => '.80',
		'attributes' => array(
			'data-conditional-id'    => $prefix . 'bg_effect',
			'data-conditional-value' => 'rainbow',
		),
	) );

	//Blended Background Color
	$cmb->add_field( array(
		'name'       => esc_html__( 'Blended Background Color', 'xevent' ),
		'id'         => $prefix . 'blended_bg',
		'type'       => 'colorpicker',
		'default'	 => '#1d77ef',
		'attributes' => array(
			'data-conditional-id'    => $prefix . 'bg_effect',
			'data-conditional-value' => 'blended',
		),
	) );

    // Overlay Background Color
    $cmb->add_field( array(
        'name'    => esc_html__( 'Overlay Background Color', 'xevent' ),
		'id'   => $prefix . 'overlay_bg',
		'type' => 'rgba_colorpicker',
		'default'  => 'rgba(0,0,0, 0.0)',
    ) );

    $cmb->add_field( array(
	    'name' => esc_html__( 'Dotted Background', 'xevent' ),
	    'desc' => 'Add dotted background (optional)',
	    'id'   => $prefix . 'dotted_bg',
	    'type' => 'checkbox'
	) );
	
	// Header Color
	$cmb->add_field( array(
		'name'    => esc_html__( 'Title Color', 'xevent' ),
		'id'      => $prefix . 'title_color',
		'type'    => 'colorpicker',
		'default' => '#ffffff',
	) );
	
    // Subheader
   $cmb->add_field( array(
		'name'       => esc_html__( 'Subhead', 'xevent' ),
		'id'         => $prefix . 'subhead',
		'type'       => 'text',
	) );
   
   // Header Text Align
   $cmb->add_field( array(
    'name'             => esc_html__( 'Header Align', 'xevent' ),
    'id'               => $prefix . 'header_align',
    'type'             => 'select',
    'show_option_none' => false,
    'default'          => 'text-left',
    'options'          => array(
        'text-left' 	=> __( 'Left', 'xevent' ),
        'text-right'	=> __( 'Right', 'xevent' ),
        'text-center'	=> __( 'Center', 'xevent' ),
    ),
) );
	
}

// Custom function for Speaker Role
function speaker_role_options() {
    return array(
		'yes' => __( 'Yes', 'xevent' ),
		'no'   => __( 'No', 'xevent' ),
    );
}