<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package XEvent
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<?php $xevent_var = get_option('xevent_var'); ?>

<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="theme-color" content="<?php echo esc_attr($xevent_var['primary_color']);?>" />

<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) { ?>
    <link rel="shortcut icon" href="<?php if(isset($xevent_var['favicon']['url'])){ echo esc_url($xevent_var['favicon']['url']);}else{} ?>" type="image/x-icon">
<?php } ?>

<link rel="apple-touch-icon" sizes="180x180" href="<?php if(isset($xevent_var['apple_touch_icon']['url'])){ echo esc_url($xevent_var['apple_touch_icon']['url']);}else{} ?>">

<?php xevent_custom_css(); ?>

<?php wp_head(); ?>

<!-- Global site tag (gtag.js) - Google Analytics -->

<script async src="https://www.googletagmanager.com/gtag/js?id=UA-76400348-49"></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());
  gtag('config', 'UA-76400348-49');
</script>	

<!-- Start of HubSpot Embed Code -->
<script type="text/javascript" id="hs-script-loader" async defer src="//js.hs-scripts.com/3830659.js"></script>
<!-- End of HubSpot Embed Code -->


</head>

<body <?php body_class(); ?>>

	<?php if (true == $xevent_var['preload']): ?>
	 <!-- PRELOADER -->
    <div id="preload" <?php if (true == $xevent_var['preload_bg_select']):?> class="preload-gradient-bg" <?php endif; ?>>
      <div class="preload-inner">
        <div class="loader"></div>
      </div>
    </div>
    <?php endif; ?>

<div id="page" class="site">

	<?php 
	  if ($xevent_var['nav_fullwidth'] == true) { $navwidth = 'container-fluid'; };
	  if ($xevent_var['nav_fullwidth'] == false) { $navwidth = 'container'; };	
	?>


	  <!-- NAVIGATION -->
    <nav class="navbar navbar-custom default">

      <?php if (true == $xevent_var['search_bar']): ?>
        <!-- Start Top Search -->
        <div class="top-search">
          <div class="<?php echo esc_attr($navwidth); ?>">
          	<form role="search" method="get" class="search-form" action="<?php echo esc_url(home_url('/')); ?>">
  	          <div class="input-group">
  	            <span class="input-group-addon"><i class="pe-2x pe-va pe-7s-search"></i></span>
  	            <input type="text" class="search-field form-control"
  		            placeholder="<?php echo esc_attr_x( 'Search', 'placeholder', 'xevent' ) ?>"
  		            value="<?php echo get_search_query() ?>" name="s"
  		            title="<?php echo esc_attr_x( 'Search for:', 'label', 'xevent' ) ?>" />
  	            <span class="input-group-addon close-search"><i class="pe-2x pe-va pe-7s-close"></i></span>
  	          </div>
  	        </form>
          </div>
        </div>
      <?php endif; ?>

      <div class="<?php echo esc_attr($navwidth); ?>">

        <div class="navbar-header">
          <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar-collapse" aria-expanded="false">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar topbar"></span>
            <span class="icon-bar middlebar"></span>
            <span class="icon-bar bottombar"></span>
          </button>

          <a href="<?php echo esc_url(home_url('/')); ?>"
		         title="<?php bloginfo('name'); ?>"
		         class="navbar-brand">
                <?php if($xevent_var['nav_logo_image']['url']){ ?>
                	<img class="logo"
                	src="<?php echo esc_url($xevent_var['nav_logo_image']['url']); ?>" alt="<?php echo bloginfo('name'); ?>"/>
                <?php } else { ?>	
                	<h3 class="navhead"><?php bloginfo('name'); ?></h3>
                <?php } ?>
		      </a>
		    </div>

    		<div class="collapse navbar-collapse" id="navbar-collapse"> 
        		<?php
              wp_nav_menu( array(
              'menu'				      => '',
              'theme_location'    => 'primary',
              'depth'             => 3,
              'container'         => 'div',
              'container_class'   => '',
              'container_id'      => '',
              'menu_class'        => 'nav navbar-nav no-float navbar-right',
              'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
              'walker'            => new wp_bootstrap_navwalker())
              );
            ?>
    		</div>

      </div>
    </nav>


	

				

               


            



