<?php

/**
 * Welcome Logic
 *
 * @since 1.0.0
 * @package WPW
 */

if ( ! defined( 'WPINC' ) ) {

    die;

}



/**
 * Welcome page redirect.
 *
 * Only happens once and if the site is not a network or multisite.
 *
 * @since 1.0.0
 */
function wpw_safe_welcome_redirect() {

    // Bail if no activation redirect transient is present.
    if ( ! get_transient( '_welcome_redirect_wpw' ) ) {

        return;

    }

  // Delete the redirect transient.
  delete_transient( '_welcome_redirect_wpw' );

  // Bail if activating from network or bulk sites.
  if ( is_network_admin() || isset( $_GET['activate-multi'] ) ) {

    return;

  }

  // Redirect to Welcome Page.
  // Redirects to `your-domain.com/wp-admin/plugin.php?page=wpw_welcome_page`.
  wp_safe_redirect( add_query_arg( array( 'page' => 'xevent' ), admin_url( 'admin.php' ) ) );


}

add_action( 'admin_init', 'wpw_safe_welcome_redirect' );

/**
 * Adds welcome page and subpage menu.
 *
 * @since 1.0.0
 */
function xevent() {

  global $xevent_submenu;
  global $xevent_menu;

  $icon_url = get_template_directory_uri(). '/img/themecube.svg';


  $xevent_menu = add_theme_page( 'xevent', 'XEvent', 'edit_theme_options', 'xevent', 'welcome_screen', 'dashicons-themecube', '2' );

  $instplugins     = add_theme_page( 'xevent', esc_attr__( 'Install Plugins', 'xevent' ), esc_attr__( 'Install Plugins', 'xevent' ), 'manage_options', 'tgmpa-install-plugins' , 'tgmpa-install-plugins' );

  if ( class_exists('ReduxFrameworkPlugin') ) {
    $rdxoptionspage  = add_theme_page( 'xevent', esc_attr__( 'Theme Options', 'xevent' ), esc_attr__( 'Theme Options', 'xevent' ), 'manage_options', '_options' , '_options' );
  }

}

add_action( 'admin_menu', 'xevent' );

/**
 * Welcome page content.
 *
 * @since 1.0.0
 */
function welcome_screen() {

    if ( file_exists( get_template_directory() . '/inc/welcome/welcome.php') ) {

       require_once( get_template_directory() . '/inc/welcome/welcome.php' );

    }
}

