<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$xevent_var = get_option('xevent_var');

 $image = wp_get_attachment_url( get_post_meta( get_the_ID(), 'tc_header_bg_id', 1 ), 'full' );
 $overlay_bg = get_post_meta( get_the_ID(), 'tc_overlay_bg', true );
 $subhead = get_post_meta( get_the_ID(), 'tc_subhead', true );
 $title_color = get_post_meta( get_the_ID(), 'tc_title_color', true );
 $align = get_post_meta ( get_the_ID(), 'tc_header_align', true );
 $dotted_bg = get_post_meta ( get_the_ID(), 'tc_dotted_bg', true );
 $bg_effect = get_post_meta( get_the_ID(), 'tc_bg_effect', true );
 $color1 = get_post_meta( get_the_ID(), 'tc_color1', true );
 $color2 = get_post_meta ( get_the_ID (), 'tc_color2', true );
 $degree = get_post_meta ( get_the_ID (), 'tc_degree', true );
 $opacity = get_post_meta ( get_the_ID (), 'tc_opacity', true );
 $blended_bg = get_post_meta ( get_the_ID (), 'tc_blended_bg', true );

 $html ='';

 $overlay_color ='';
 if($overlay_bg){$overlay_color = 'style=background-color:'.$overlay_bg.'';}

 $title_style = '';
 if($title_color){$title_style = 'style=color:'.$title_color.'';}

 $dotted = '';
 if($dotted_bg) {$dotted = 'dotted_bg';}

 $bg_image ='';
 if($image){$bg_image ='background-image:url('.$image.');';}

 $gradient_options ='';
 if(($bg_effect) == 'rainbow') {
  $gradient_options = 'data-type=linear data-degrees='.$degree.' data-color='.$color1.'-'.$color2.' data-opacity='.$opacity.'';}

 $blendcss = '';
 if(($bg_effect) == 'blended'){$blendcss = 'background-color:'.$blended_bg.';';}

get_header( 'shop' ); ?>

<div id="header-<?php the_ID(); ?>" class="<?php echo esc_html($bg_effect); ?> header header-shop" <?php echo esc_html($gradient_options); ?> style="<?php echo esc_html($bg_image); ?> <?php echo esc_html($blendcss); ?>" >
  <div class="inner <?php echo esc_html($dotted); ?>" <?php echo esc_html($overlay_color); ?>>

    <div class="container">
      <div class="row">
        
        <div class="col-lg-12 <?php echo esc_html($align) ?>">
            <?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
				<h1 class="page-title"><?php woocommerce_page_title(); ?></h1>
			<?php endif; ?>
			<?php if($subhead){ echo '<p '.$title_style.' class="subhead">'.$subhead.'</p>'; } ?>

			<?php do_action('woo_custom_breadcrumb'); ?>
        </div>

      </div>
    </div>
  </div>
</div>

	<?php
		/**
		 * woocommerce_before_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
		 * @hooked woocommerce_breadcrumb - 20
		 * @hooked WC_Structured_Data::generate_website_data() - 30
		 */
		do_action( 'woocommerce_before_main_content' );
	?>

<div class="container">
	<div class="row">
		<div class="col-lg-12">

		<?php
			/**
			 * woocommerce_archive_description hook.
			 *
			 * @hooked woocommerce_taxonomy_archive_description - 10
			 * @hooked woocommerce_product_archive_description - 10
			 */
			do_action( 'woocommerce_archive_description' );
		?>

		</div>

		<div class="col-lg-9">
			<?php if ( have_posts() ) : ?>

				<?php
					/**
					 * woocommerce_before_shop_loop hook.
					 *
					 * @hooked woocommerce_result_count - 20
					 * @hooked woocommerce_catalog_ordering - 30
					 */
					do_action( 'woocommerce_before_shop_loop' );
				?>

				<?php woocommerce_product_loop_start(); ?>

					<?php woocommerce_product_subcategories(); ?>

					<?php while ( have_posts() ) : the_post(); ?>

						<?php
							/**
							 * woocommerce_shop_loop hook.
							 *
							 * @hooked WC_Structured_Data::generate_product_data() - 10
							 */
							do_action( 'woocommerce_shop_loop' );
						?>

						<?php wc_get_template_part( 'content', 'product' ); ?>

					<?php endwhile; // end of the loop. ?>

				<?php woocommerce_product_loop_end(); ?>

				<?php
					/**
					 * woocommerce_after_shop_loop hook.
					 *
					 * @hooked woocommerce_pagination - 10
					 */
					remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
					do_action( 'woocommerce_after_shop_loop' );
				?>

			<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

				<?php
					/**
					 * woocommerce_no_products_found hook.
					 *
					 * @hooked wc_no_products_found - 10
					 */
					do_action( 'woocommerce_no_products_found' );
				?>

			<?php endif; ?>

		</div>

	
	<div class="col-lg-3">

		<?php
			/**
			 * woocommerce_sidebar hook.
			 *
			 * @hooked woocommerce_get_sidebar - 10
			 */
			do_action( 'woocommerce_sidebar' );
		?>

	</div>

</div>
</div>

<div class="custom-pagination">
	<?php add_action( 'woocommerce_after_main_content', 'woocommerce_pagination', 5 ); ?>

	<?php
		/**
		 * woocommerce_after_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
		 */
		do_action( 'woocommerce_after_main_content' );
	?>

</div>


<?php get_footer( 'shop' ); ?>
